# python-AT30TS00-sensor
Python 3 module for AT30TS00 temperature sensor reading. It uses I2C to talk to the AT30TS00.
At the moment it only supports initialisation and simple temperature reading, no alarms etc.

See [here](https://www.microchip.com/wwwproducts/en/AT30TS00) for the official datasheet at Microchip
